@@ -128,16 +128,20 @@ impl<'c> JsonCodec for PgValueRef<'c> {
                 return Ok(new_json_option_into!(r));
             }
             "UUID" => {
-                let r: Option<String> = Decode::<'_, Postgres>::decode(self)?;
+                let r: Option<Uuid> = Decode::<'_, Postgres>::decode(self)?;
                 if let Some(r) = r {
-                    return Ok(serde_json::Value::String(r));
+                    return Ok(serde_json::Value::String(r.to_string()));
                 }
                 return Ok(serde_json::Value::Null);
             }
             "UUID[]" => {
-                let r: Option<Vec<String>> = Decode::<'_, Postgres>::decode(self)?;
+                let r: Option<Vec<Uuid>> = Decode::<'_, Postgres>::decode(self)?;
                 if let Some(r) = r {
-                    return Ok(serde_json::Value::from(r));
+                    let mut arr =vec![];
+                    for x in r {
+                        arr.push(x.to_string());
+                    }
+                    return Ok(serde_json::Value::from(arr));
                 }
                 return Ok(serde_json::Value::Null);
             }
